# Dapr - Governance Review for Graduation

What follows is a governance review and assessment for the Dapr project. This review is carried out by members of the Governance Working Group of TAG Contributor Strategy.  
The review may have been done because of a change in maturity level for the project, at the request of the TOC, or as a request by the project itself. 
If requested by the project, the review will be provided to the project maintainers. Otherwise, the review will be submitted to the TOC for their follow-up.

Governance reviews contribute to the health and sustainability of the CNCF projects. By providing guidance on effective governance practices, TAG Contributor Strategy aims to ensure that projects operate efficiently, encourage diverse participation, and uphold the values of the CNCF. The governance review process is designed to be constructive and supportive, aiming to assist projects in refining their governance models and addressing any challenges they may face.

Projects may ask TAG Contributor Strategy for assistance in resolving any issues uncovered by the review. The TAG is available via our [Slack channel](https://cloud-native.slack.com/archives/CT6CWS1JN), [email](https://lists.cncf.io/g/cncf-tag-contributor-strategy), [GitHub](https://github.com/cncf/tag-contributor-strategy), or by joining our weekly meetings (listed on the [CNCF public calendar](https://www.cncf.io/calendar/)).

## Summary and Assessment

Status: Exemplary

### Executing the Assessment

[Mark Fussell](https://github.com/msfussell) [requested a review on September 4th, 2024](https://github.com/cncf/tag-contributor-strategy/issues/702) as part of [Dapr’s Graduation Application](https://github.com/cncf/toc/issues/1354).

[Ed Robinson](https://github.com/edrob999) and [Bob Killen](https://github.com/mrbobbytables/) executed the review in early October 2024.

### Critical Items

No issues have been identified that need to be resolved before Graduation.

### Points of Excellence

The following aspects of governance are exemplary, and can be referenced as examples for other projects to copy:

* Dapr has an extensive definition for a [community manager](https://github.com/dapr/community/blob/master/COMMUNITY-MANAGER.md) role;  excellent getting-started, quickstarts documentation   
* The project has intentionally ensured maintainer and steering group members have diverse company affiliation. No company has \>50% representation.  
* Rotation of members and limiting access to GitHub and 1password with terms assigned to admins and max \# of admins is a good demonstration of security best practices.  
* Contributor docs are well laid out and the addition of a guide explicitly for codespaces makes the project more broadly accessible.

### Areas for Improvement

These are considered non-blocking for advancement to Graduation:

* While not a significant issue, Dapr could adopt usage of GitHub org management tool that would allow “gitops” style management. This would reduce overhead of the STC and GitHub admin team making it easier to manage access and general maintainer status as well as be more transparent.  
* The project has functioning leadership, with responsibilities spread between maintainers and steering group members. We recommend either consolidating or cross linking to assist discoverability of roles and responsibilities.

More details can be found in the [Governance Findings Table](#governance-findings-table)

## Review

### Governance Description

Dapr uses a simple Maintainer Council-style governance with the primary governance body referred to as the [Steering and Technical Committee (STC)](https://github.com/dapr/community/blob/2d825592d0ff0e9c4544cfe03899f29ce14fecd1/steering-and-technical-committee-charter.md). The STC is responsible for both community governance and project technical oversight. They have good guardrails with terms and limitations on max company representation.

### Discoverability

Dapr’s project governance is collectively in their [community repo](https://github.com/dapr/community/) with links to the various parts it directly available in the [README](https://github.com/dapr/community/tree/2d825592d0ff0e9c4544cfe03899f29ce14fecd1?tab=readme-ov-file#other-documents). Dapr’s website links to the community repo directly from its home page making the governance docs easily discoverable.

There are two minor non-blocking suggestions:  
1\) It’d be good to add a link to the community repo in the [org .github profile](https://github.com/dapr/.github/tree/main/profile). This would make it equally discoverable in github as it is on the website.  
2\) There is a [GOVERNANCE.md](https://github.com/dapr/dapr/blob/8b8b6052b49391985d9b95eec08f8729ed1562ab/GOVERNANCE.md) file in the dapr repo itself that outlines the maintainer role. To reduce the chance of it becoming out of sync with the [maintainer role defined in community-membership.md](https://github.com/dapr/community/blob/2d825592d0ff0e9c4544cfe03899f29ce14fecd1/community-membership.md#maintainer), it would be good to remove the information and link to the canonical source of truth.

*Contributor Docs*  
Dapr’s contributor docs are located on their [website](https://docs.dapr.io/contributing/). Their docs are thorough, provide a short description of the [primary repos](https://docs.dapr.io/contributing/contributing-overview/#dapr-repository-index), and include a section on [developing with Codespaces](https://docs.dapr.io/contributing/codespaces/) to reduce friction for contributors.  
One minor suggestion would be to add an explicit link to the contributor guide in the  [org .github profile](https://github.com/dapr/.github/tree/main/profile). There is a general docs link, but a separate one for the contributor guide would likely be worth it.

### Documentation Content

The following table details the governance areas expected for a project. Coverage is indicated by Complete, Partial, Missing, and Unknown.

* Complete \- the content of the governance documentation is fully detailed and does not leave any question to the reader.  
* Partial \- the content of the governance documentation is missing some information and would leave the reader with questions or some level of misunderstanding.  
* Missing \- the documentation is absent, wholly undiscoverable, or woefully inadequate in meeting the objectives of that governance content. The reader cannot act on the content that is available.  
* Unknown \- status cannot be assessed at this time

| Governance Area | Coverage | Documents | Finding Notes |
| :---- | :---- | :---- | :---- |
| Project Purpose | Complete | [README.md](https://github.com/dapr/dapr/blob/b9843e84a86b924255f9ab115c4d163cca9593b7/README.md) | Purpose is clearly defined in “Any language, any framework, anywhere” section at top of the Readme |
| Maintainer List | Complete | [MAINTAINERS.md](https://raw.githubusercontent.com/dapr/community/87c5c080e212cd906c1c9fad2df302f60bb06a12/MAINTAINERS.md) | Maintainer list is up-to-date |
| Code of Conduct | Complete | [CODE-OF-CONDUCT.md](https://github.com/dapr/community/blob/5619993d298893bb61614bf81e1a431adb8326ce/CODE-OF-CONDUCT.md) | Code-of-conduct is a stub to contributor-covenant code of conduct, with dedicated reporting. We recommend ensuring conduct reports are administered by an independent group, with escalation to CNCF if there is a conflict.  |
| Contributor Guide | Complete | [https://docs.dapr.io/contributing/](https://docs.dapr.io/contributing/) | Extensive contributor guide |
| Contributor Ladder | Complete | [community-membership.md](https://github.com/dapr/community/blob/9f4f7ed051add7deaba4bc64ef2cd6373e364045/community-membership.md) | Complete contributor ladder guide |
| Maintainer Lifecycle  | Complete | [GOVERNANCE.md](https://github.com/dapr/dapr/blob/bfadcd1ceed5e0edb4004de5a0a77b984c5f1786/GOVERNANCE.md)<br>[Emeritus defined for STC](https://github.com/dapr/community/issues/438)<br>[Maintainer activity policy](https://github.com/dapr/community/blob/9f4f7ed051add7deaba4bc64ef2cd6373e364045/community-membership.md\#responsibilities-and-privileges-2) | The maintainer list is up to date. The maintainer lifecycle is documented. Emeritus are recorded. |
| Decision-making | Complete | [GOVERNANCE.md](https://github.com/dapr/dapr/blob/bfadcd1ceed5e0edb4004de5a0a77b984c5f1786/GOVERNANCE.md) | Decision making is well documented for the STC |
| Code and Docs Ownership | Complete | [ADMINISTRATORS.md](https://github.com/dapr/community/blob/f6be56baada528f462d0312fc80795e49cb8ef6c/ADMINISTRATORS.md) | Ownership is administered by an administrator |
| Security Reporting and response | Complete | [SECURITY.md](https://github.com/dapr/dapr/blob/41bbb7322b757e547da63476aba0d35ec346312a/SECURITY.md) -> [https://docs.dapr.io/operations/support/support-security-issues/](https://docs.dapr.io/operations/support/support-security-issues/) | Original issues were raised by dims in this issue: [https://github.com/dapr/community/issues/532](https://github.com/dapr/community/issues/532) All issues outlined have been resolved |
| Communication and Meetings | Complete | https://www.youtube.com/@DaprDev/streams | Regular community meetings are recorded and meeting notes/agendas in GitHub issues |

#### Sub-projects, plugins, and related

There are 34 sub projects/repos. Here are the pinned repos:

| Area | Ownership and Operation | Standing Bodies | Project Alignment | Notes |
| :---- | :---- | :---- | :---- | :---- |
| [Dapr](https://github.com/dapr/dapr) | Complete | Complete | Complete | Primary repo, with same ownership/bodies/alignment as org |
| [docs](https://github.com/dapr/docs) | Complete | Complete | Complete | Documentation repo, with dedicated ReadMe containing usage/contributing instructions. No OWNERSHIP file, but not required |
| [cli](https://github.com/dapr/cli) | Complete | Complete | Complete | Command line interface repo. Dedicated Readme with complete instructions |
| [components-contrib](https://github.com/dapr/components-contrib) | Complete | Complete | Complete | Community contribution repo. 246 contributors. Dedicated Readme with complete instructions |
| [quickstarts](https://github.com/dapr/quickstarts) | Complete | Complete | Complete | Scenario based Quickstarts repo. Dedicated ReadMe |
| [community](https://github.com/dapr/community) | Complete | Complete | Complete | Community repo, with complete documentation \+ ReadMe |

### Operation

#### Transparency and freshness

The project’s governance docs and transparency activities are active and up to date.

* Dapr holds regular recorded [community meetings](https://www.youtube.com/@DaprDev/streams) with [GitHub issues being used for agendas and notes](https://github.com/dapr/community/issues?q=+label%3A%22community+call%22+).  
* The STC uses [GitHub issues for agendas and notes with records going back to 2022](https://github.com/dapr/community/issues?q=is%3Aissue+%22Steering+and+Technical+Committee+%28STC%29+meeting%22+).

#### Governance Drift

The project **does not** experience governance drift as indicated by consistent steering group minutes, leadership rotation, adherence to maintainer membership change processes.

#### GitHub & Code Ownership

Dapr has delegated management of GitHub permissions and teams to the [administrator role](https://github.com/dapr/community/blob/2d825592d0ff0e9c4544cfe03899f29ce14fecd1/ADMINISTRATORS.md) accompanied by usage of [CODEOWNERS](https://docs.github.com/en/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners) in the repos. The [MAINTAINERS.md](https://github.com/dapr/community/blob/2d825592d0ff0e9c4544cfe03899f29ce14fecd1/MAINTAINERS.md) file is not used for automated management, but a reflection of public information regarding the maintainers and their affiliations.

### Maintainer List(s)

The project's maintainer list(s) are\] current. Individuals on the maintainer list do  appear to match the requirements of maintainership in accordance with the project's documented requirements. The maintainer affiliations (employers) reflect Balanced diversity.

Community spread is OK. 21 maintainers affiliated with 8 companies: Microsoft 10; Diagrid 5; 1 each Nirmata, Stripe, Intel, Automattic, Independent, Proximus

Maintainers must show activity in the last three months. 19 of the 21 maintainers have PR review activity in the last three months [(to October 2\)](https://dapr.devstats.cncf.io/d/29/pr-reviews-by-contributor?orgId=1&from=now-3M&to=now%2Fy&var-period=d&var-repo_name=All&var-reviewers=%22artursouza%22&var-reviewers=%22msfussell%22&var-reviewers=%22cicoyle%22&var-reviewers=%22salaboy%22&var-reviewers=%22yaron2%22&var-reviewers=%22JoshVanL%22&var-reviewers=%22philliphoff%22&var-reviewers=%22WhitWaldo%22&var-reviewers=%22artur-ciocanu%22&var-reviewers=%22mikeee%22&var-reviewers=%22elena-kolevska%22&var-reviewers=%22hhunter-ms%22&var-reviewers=%22ItalyPaleAle%22&var-reviewers=%22paulyuk%22&var-reviewers=%22KrylixZA%22&var-reviewers=%22antontroshin%22&var-reviewers=%22daixiang0%22&var-reviewers=%22mukundansundar%22&var-reviewers=%22filintod%22&var-reviewers=%22rochabr%22&var-reviewers=%22marcduiker%22&var-reviewers=%22sicoyle%22&var-reviewers=%22berndverst%22&var-reviewers=%22eddumelendez%22&var-reviewers=%22cgillum%22&var-reviewers=%22Eileen-Yu%22&var-reviewers=%22yevgen-el8%22&var-reviewers=%22m3nax%22&var-reviewers=%22charan2628%22&var-reviewers=%22DeepanshuA%22&var-reviewers=%22fowlerlee%22&var-reviewers=%22arslanmusta%22&var-reviewers=%22withinboredom%22&var-reviewers=%22ytimocin%22&var-reviewers=%22stephane-dereppe%22&var-reviewers=%22lburgazzoli%22&var-reviewers=%22evhen14%22&var-reviewers=%22humandigital-michiel%22&var-reviewers=%22DropSnorz%22&var-reviewers=%22AnnuCode%22&var-reviewers=%22famarting%22&var-reviewers=%22SantoDE%22&var-reviewers=%22greenie-msft%22&var-reviewers=%22alicejgibbons%22&var-reviewers=%22passuied%22&var-reviewers=%22luigirende%22&var-reviewers=%22BlackRider97%22&var-reviewers=%22frankbuckley%22&var-reviewers=%22Arhell%22&var-reviewers=%22erwinkramer%22&var-reviewers=%22pimmerks%22&var-reviewers=%22joebowbeer%22&var-reviewers=%22olitomlinson%22&var-reviewers=%22onionhammer%22&var-reviewers=%22halspang%22&var-reviewers=%22cecilphillip%22&var-reviewers=%22valentin-p%22&var-reviewers=%22qustavo%22&var-reviewers=%22none%22), with a range of 1 to 406 PR reviews. The two maintainers without activity have entered PRs to be removed. This activity indicates the project governance is being adhered to.

### Evolution

The Governance document has two sections, describing:  
* project maintainers (adding, removing, active requirement),
* Code of conduct (linking to Contributor covenant code of conduct),
* Plus a note on how changes to the code of conduct are approved  
STC was [bootstrapped in 2021](https://github.com/dapr/community/pull/83) bringing about more formal written governance, there have been no recent material changes (except the addition of the administrator role). It is very simple guidance to follow, and with a large group of functioning maintainers, the project does not require additional written governance, although adding documentation will help for transparency and as a reference for other projects.

### Governance Findings Table

| Finding | Importance | Description |
| :---- | :---- | :---- |
| Single GitHub admin | Low | There is currently a single [GitHub administrator](https://github.com/dapr/community/blob/2d825592d0ff0e9c4544cfe03899f29ce14fecd1/ADMINISTRATORS.md#current-administrators). We suggest adding an additional member to avoid the work being dependent on a single person. **NOTE:** The STC does have a similar level of permissions and would be able to work in a “break glass” scenario.  |
| No usage of GitHub membership/permissions tooling | Low | Dapr has good controls around org membership and teams with limiting access to a small subset of members. This could be improved by adopting some tooling such as [clowarden](https://github.com/cncf/clowarden), [prow & peribolos](https://docs.prow.k8s.io/docs/components/cli-tools/peribolos/), [sheriff](https://github.com/electron/sheriff) or other tool that can manage org membership & permissions in a more transparent manner. |
| Governance and contributing docs should be discoverable from GitHub Org “home” | Low | The [org .github profile](https://github.com/dapr/.github/tree/main/profile) currently does not link to the community repo and links to the root docs site, but not the contributor guide.  It would aid in discoverability if both were linked to mirror the website. |

### Previous Reviews

There are no previous governance reviews

