# Governance Review Template

What follows is a governance review and assessment for the Karmada project. This review is carried out by members of the Governance Working Group of TAG Contributor Strategy. The review may have been done because of a change in maturity level for the project, at the request of the TOC, or as a request by the project itself. If requested by the project, the review will be provided to the project maintainers. Otherwise, the review will be submitted to the TOC for their follow-up.

Projects may ask TAG Contributor Strategy for assistance in resolving any issues uncovered by the review. The TAG is available via our [slack channel](https://cloud-native.slack.com/archives/CT6CWS1JN), [email](https://lists.cncf.io/g/cncf-tag-contributor-strategy), [GitHub](https://github.com/cncf/tag-contributor-strategy), or by joining our weekly meetings (listed on the [CNCF public calendar](https://www.cncf.io/calendar/)).

## Summary and Assessment

Status: Mostly Satisfactory

The Karamada governance seems well thought out and fitting for the project, but also does not seem to be kept completely up to date. Inactive maintainers should be removed and the membership and level of other people within the community should have a single source of truth.

### Executing the Assessment

This assesment was conducted by Bill Mulligan (Isovalent) in August 2023.

### Must-Fix Items

The following issues have been identified that need to be resolved before [project milestone or other requirement]:

* Update the list of maintainers
* Harmonize the Code of Conduct across the project

### Areas for Improvement

Over the next year, the project should work on the following issues to improve its governance, these are considered non-blocking:

* Make community membership publicly trackable
* Synchronize OWNERS files and make sure the APPROVERS and REVIEWERS are up to date

## Review

### Governance Description

Karmada is governed by a simple Maintainer Council-style governance, where there are a small group of Maintainers who perform all governance functions for the project. This is an extremely common governance structure and satisfactory for a variety of projects.

### Discoverability

#### Governance Location

[Governance documentation](https://github.com/karmada-io/community/blob/main/GOVERNANCE.md) may be found in Karmada's community [repo](https://github.com/karmada-io/community/tree/main). The following parts of Karmada's governance are well-defined in this documentation:

- Values
- Maintainer voting procedures
- Official project communications channels and meetings
- Contributor Ladder
- Code of Conduct

#### Governance Discovery Completeness

The governance documentation is not currently linked in the main repo. While the project has added a contributor ladder, linking to these documents from within the governance section of the main repo and documentation would make them easier for people to find.

### Documentation Content

The following table details the governance areas expected for a project. Coverage at this [commit](https://github.com/karmada-io/community/commit/e73fcc3c9c7b7babc4a2d8bdf19005a31a3d6843) is indicated by Complete, Partial, and Missing.

* Complete - the content of the governance documentation is fully detailed and does not leave any question to the reader.
* Partial - the content of the governance documentation is missing some information and would leave the reader with questions or some level of misunderstanding.
* Missing - the documentation is absent, wholly undiscoverable, or woefully inadequate in meeting the objectives of that governance content. The reader cannot act on the content that is available.
* Unknown - status cannot be assessed at this time

| Governance Area | Coverage | Documents | Finding Notes |
|:----------------|:--------:|:------:|:--------------|
| Project Purpose | Complete | [Docs](https://karmada.io/docs/) and [README](https://github.com/karmada-io/karmada/tree/master#why-karmada)| |
| Maintainer List | Complete | [MAINTAINERS.md](https://github.com/karmada-io/karmada/blob/master/MAINTAINERS.md) | It has been the same 7 people since the file was created |
| Code of Conduct | Partial | [Main repo](https://github.com/karmada-io/karmada/blob/master/CODE_OF_CONDUCT.md) and [Community repo](https://github.com/karmada-io/community/blob/main/CODE_OF_CONDUCT.md) | Karmada currently has two CoCs, it would be helpful to clarifiy which they are using |
| Contributor Guide | Complete | [CONTRIBUTING.md](https://github.com/karmada-io/karmada/blob/master/CONTRIBUTING.md) | Could be helpful to flesh this out and make it more project specific |
| Contributor Ladder | Partial | [Community Membership](https://github.com/karmada-io/community/blob/main/community-membership.md) | The roles are laid out, but the owners files are not in synce with the approvers and reviewers |
| Maintainer Lifecycle | Partial | [Community Membership](https://github.com/karmada-io/community/blob/main/community-membership.md#maintainer) | Adding emeritus process when revoking would be helpful |
| Decision-making | Complete | [Voting](https://github.com/karmada-io/community/blob/main/GOVERNANCE.md#voting) | Mainly based on lazy consensus |
| Code and Docs Ownership | Partial | [Owners](https://github.com/karmada-io/community/blob/main/OWNERS), [Owners](https://github.com/karmada-io/karmada/blob/master/OWNERS), [Approvers](https://github.com/karmada-io/community/blob/main/APPROVERS.md), and [Reviewers](https://github.com/karmada-io/community/blob/main/REVIEWERS.md) | All of the files are currently out of sync with each other. It would be helpful to have a single source of truth |
| Security Reporting and response | Complete | [Security.md ](https://github.com/karmada-io/community/blob/main/security-team/SECURITY.md)| |
| Communication and Meetings | Complete | [Meetings](https://github.com/karmada-io/karmada/blob/master/README.md#meeting) | This would be helpful to link or reference in the contributing guide |

#### Sub-projects, plugins, and related

The project includes the following sub-projects, plugins, and other notable divisions:

None

### Operation

The community meeting [doc](https://docs.google.com/document/d/1y6YLVC-v7cmVAdbjedoyR5WL0-q45DBRXTvz5_I7bkA/edit#heading=h.g61sgp7w0d0c) has a lively history of meetings and topics. The Karmada [Slack](https://cloud-native.slack.com/archives/C02MUF8QXUN) channel is active with responses from the community, but it seems there are less answers in the Karmada dev [channel](https://cloud-native.slack.com/archives/C02NDR16M3K).

#### Transparency and freshness

Transparency for a project is exemplified in the public documentation, record, and communications, allowing observers and contributors to monitor the project's adherence to their stated governance. Freshness indicates governance activities mirror the documented governance for the project, and have been reviewed or updated recently.

The project's governance documentation and activities are not currently up to date. The project currently has two different owners files in different repos ([Owners](https://github.com/karmada-io/community/blob/main/OWNERS) and [Owners](https://github.com/karmada-io/karmada/blob/master/OWNERS)) and the community ladder currenly links to a third [Owners](https://github.com/karmada-io/community/blob/main/contributors/guide/owners.md) that is currently empty. 

The [Approvers](https://github.com/karmada-io/community/blob/main/APPROVERS.md) is a relatively new and appears up to date while the [Reviewers](https://github.com/karmada-io/community/blob/main/REVIEWERS.md) has not been updated very much since it was created. This file is also out of sync with the number listed in the incubation proposal, but it likely because that document was created in December 2022.

There are currently 6 outstanding [requests](https://github.com/karmada-io/community/issues) for community membership, some as old as 7 weeks. Community membership is also not tracked publically so it is hard to tell how many members there are. 

#### Governance Drift

The project does experience governance drift as indicated by inactive maintainers and no new maintainer onboarding.

#### Ownership

The project's ownership evaluation did not leverage Sheriff, the CNCF GitHub permission auditing tool.

The project's permissions and ownership settings and files were not checked.

### Maintainer List(s)

The project's maintainer list is not current. Individuals on the maintainer list do not appear to match the requirements of maintainership in accordance with the project's documented requirements. The maintainer affiliations (employers) reflect Balanced diversity. Based on a review of the Devstats data:

@mrlihanbo has not contributed since August 2022
@carmark has not contributed since August 2021
@zoroyouxi has no public contributions
@lfbear has not contributed since December 2021

### Evolution

Governance evolution is the observable changes and improvements the project makes to its governance over the project's lifespan. It is expected that changes will occur over the project's life and that such changes are iterative, tested, and adjusted.

Major milestones in the project's governance over time include:

* From the Incubation [doc](https://github.com/cncf/toc/pull/986) "We attach great importance to developers and our community has matured significantly. We have established the community membership and wrote a solid contributor guide. Based on this open and transparent mechanism, developers can continue to grow while equally participating in the project. We have established a mature mentor mechanism in the community. Some active and qualified contributors, mentored attentively, have been promoted to members or maintainers. Also, we are actively involved in various open source events, such as LFX mentorship, helping college students better grow in the open source community."

Recent changes to the governance include:

* None, the governance was set up and hasn't been changed since then

Areas of potential future development include:

* Keep the community membership up to date

### Governance Findings Table

| Finding Title | Importance | Description | Links | Notes & Impact |
|:------------- |:----------:|:------------|:------|:---------------|
| Inactive maintainers | High | Inactive maintainers should be moved to Emeritus | [Maintainers](https://github.com/karmada-io/karmada/blob/master/MAINTAINERS.md) | It is important to remove commit access when maintainers are no longer active in the project |
| Conflicting Owners Files | High | Owners files should have a single source of truth | [Owners](https://github.com/karmada-io/community/blob/main/OWNERS)  [Owners](https://github.com/karmada-io/karmada/blob/master/OWNERS) [Owners](https://github.com/karmada-io/community/blob/main/contributors/guide/owners.md) | It is hard to understand who runs the project when there are conflicting sources of truth |
| Conflicting Code of Conducts | High | There should be a single CoC across the project | [Main repo](https://github.com/karmada-io/karmada/blob/master/CODE_OF_CONDUCT.md) and [Community repo](https://github.com/karmada-io/community/blob/main/CODE_OF_CONDUCT.md) | There are two conflicting CoCs in the project, one should be chosen and should be inclusive of the current CNCF CoC.|

### Previous Reviews

First review
