# KubeEdge Governance Review

What follows is a governance review and assessment for the KubeEdge project. This review is carried out by members of the Governance Working Group of TAG Contributor Strategy. The review may have been done because of a change in maturity level for the project, at the request of the TOC, or as a request by the project itself. If requested by the project, the review will be provided to the project maintainers. Otherwise, the review will be submitted to the TOC for their follow-up.

Governance reviews contribute to the health and sustainability of the CNCF projects. By providing guidance on effective governance practices, TAG Contributor Strategy aims to ensure that projects operate efficiently, encourage diverse participation, and uphold the values of the CNCF. The governance review process is designed to be constructive and supportive, aiming to assist projects in refining their governance models and addressing any challenges they may face.

Projects may ask TAG Contributor Strategy for assistance in resolving any issues uncovered by the review. The TAG is available via our [Slack channel](https://cloud-native.slack.com/archives/CT6CWS1JN), [email](https://lists.cncf.io/g/cncf-tag-contributor-strategy), [GitHub](https://github.com/cncf/tag-contributor-strategy), or by joining our weekly meetings (listed on the [CNCF public calendar](https://www.cncf.io/calendar/)).

## Summary and Assessment

Status: Mostly Satisfactory

KubeEdge demonstrates excellent public governance showing how a project runs when it has been a shared community effort from inception. They have plans to grow and develop their governance.  The project just needs to finish making the transition to the new Technical Steering Committee (TSC) model.

### Executing the Assessment

@wbc6080 of the KubeEdge project [requested](https://github.com/cncf/tag-contributor-strategy/issues/637) a governance review on May 6 in preparation for their Graduation.  On June 10, CNCF staff requested that the TAG accelerate this review as it is the remaining checklist item for their graduation.

Parts of the text for this review have been taken from the project's self-assessment.  The remainder is based on the project's files and repositories, and the answer to a couple of questions from project leader Fei Xu.

### Critical Items

The following issues have been identified that need to be resolved before Graduation:

* **Complete the Transition to the New Governance**:  Currently the governance for KubeEdge still contains both the old and new leadership structures, with no clarity on which things are going to be removed or how old and new teams relate to each other.  Particularly, it is unclear whether the Core Maintainers will exist in the future and, if so, how they fit into the project governance.
* **Security Response Information**: KubeEdge has defined both a SIG-Security and a Security Team, but not how those relate to each other (or even if there should be both). Security reporting information should be more easily findable, and it should be clear how members of the Security Team (or SIG) get appointed and replaced.

### Points of Excellence

The following aspects of governance are exemplary, and can be referenced as examples for other projects to copy:

* Maturing Governance: The project is making the transition to a chartered two-tier governance system and documenting that extensively. This is a good example for growing governance as the project grows.
* Implementing SIGs: KubeEdge has done a good job of implementing a SIG system and starting to build it out.  For other projects looking to do this that are daunted by the complexity of Kubernetes, this one can serve as an example.
* Vendor Neutrality: KubeEdge has a well-implemented vendor-independent leadership structure and roadmap.
* Public Meeting Participation: They have done a good job of driving high participation in contributor meetings, despite the need to hold them in two time zones.

### Areas for Improvement

Over the next year, the project should work on the following issues to improve its governance, these are considered non-blocking:

* Clarify which roles in the contributor ladder are per-SIG roles, and which are overall project roles, and make sure that all existing roles are reflected in the ladder. While revising the contributor ladder, also consider whether the number of senior project roles (Approver, Maintainer, Owner, Core Maintainer, SIG Lead) are actually warranted by the number or participants in the project, or whether some of them could be consolidated.
* Consider translating the governance documentation into Chinese, since the majority of contributors are Chinese and it would make leadership roles more accessible.
* Make sure that other project repositories link to the Community Repo where it is appropriate.
* If the project is going to handle its own initial CoCC reports, then there needs to be a defined response team and controlled email address for reports, whether that team is the TSC or a committee. Please reach out to the CNCF CoCC for help with this.
* The Contributor Guide could be expanded, possibly including testing and troubleshooting guides, more information on the KubeEdge architecture and subprojects, and an explanation of how PRs get approved via Prow.
* Start taking complete meeting notes on community and SIG meetings to allow asynchronous community participation.  Keeping videos up to date would also help with this, but taking notes is easier to implement.

Details of these issues can be found in the [Findings Table](#Governance-Findings-Table) and the related sections below.

## Review

### Governance Description

KubeEdge is a complex project with multiple levels of governance, including multiple subprojects and SIGs.  Its governance is modeled on Kubernetes' governance, and many of the confusing aspects of the written governance are copied from Kubernetes.

The community governance of KubeEdge is mainly divided into the [Technical Steering Committee](https://github.com/kubeedge/community/tree/f3548585203cd39e0675836bf526087807091d81/committee-technical-steering) (TSC), [Special Interest Groups](https://github.com/kubeedge/community/tree/f3548585203cd39e0675836bf526087807091d81) (SIG), and  [Working Groups](https://github.com/kubeedge/community/tree/f3548585203cd39e0675836bf526087807091d81) (WG). The KubeEdge community has 7 Technical Steering Committee members from 6 companies, who are the governing body for the KubeEdge project, providing decision-making and oversight pertaining to the KubeEdge project bylaws. The Technical Steering Committee also defines the project values and structure.

KubeEdge currently has 10 SIGs, and each SIG has at least one or two Chairs and Tech leaders, who focus on maintaining corresponding modules. This totals 15 or so SIG leaders. KubeEdge has one WG. Working Groups provide a formal avenue for disparate groups to collaborate around a common problem, craft a balanced position, and are dissolved by TSC after the problem solved.

KubeEdge also has a set of [12 core maintainers](https://github.com/kubeedge/kubeedge/blob/86f768b89dd084ff913014813c2da4dfa33aa8f2/MAINTAINERS.md) from 7 companies, who are responsible for maintaining code development for overall projects.  The role of these core maintainers, and their relationship with other groups, is not defined in the governance.

### Discoverability

#### Governance Location

The majority of governance documents are located in the [KubeEdge Community Repo](https://github.com/kubeedge/community).

#### Governance Discovery

Most governance documents are in the Community repository, making them relatively findable through GitHub by contributors who are familiar with the "community repo" convention.  However, that repository is not linked from other repositories in the KubeEdge organization, so contributors who are new to the CNCF might not find it.  

The governance is [included in the main online documentation](https://release-1-17.docs.kubeedge.io/docs/community/governance), making it very discoverable there.

### Documentation Content

<!--- Provide the commit of the file under evaluation as a point-in-time reference to this review. --->

The following table details the governance areas expected for a project. Coverage is indicated by Complete, Partial, Missing, and Unknown.
* Complete - the content of the governance documentation is fully detailed and does not leave any question to the reader.
* Partial - the content of the governance documentation is missing some information and would leave the reader with questions or some level of misunderstanding.
* Missing - the documentation is absent, wholly undiscoverable, or woefully inadequate in meeting the objectives of that governance content. The reader cannot act on the content that is available.
* Unknown - status cannot be assessed at this time

| Governance Area | Coverage | Documents | Finding Notes |
|:----------------|:--------:|:------:|:--------------|
| Project Purpose | Mostly Complete | [Readme](https://github.com/kubeedge/kubeedge/blob/aa71c0dad7936585532db2f13fd2a555d71754a6/README.md) | Could use In/out of scope section |
| Maintainer List | Complete | [maintainers](https://github.com/kubeedge/kubeedge/blob/86f768b89dd084ff913014813c2da4dfa33aa8f2/MAINTAINERS.md) | |
| Code of Conduct | Complete | [conduct](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/CODE_OF_CONDUCT.md) | See CoCC finding |
| Contributor Guide | Complete | [contributing](https://github.com/kubeedge/kubeedge/blob/86f768b89dd084ff913014813c2da4dfa33aa8f2/CONTRIBUTING.md) | |
| Contributor Ladder | Partial | [membership](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/community-membership.md#kubeedge-community-membership) | Ladder has many roles, but they don't seem to match the actual project |
| Maintainer Lifecycle | Partial | [maintainers](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/community-membership.md#kubeedge-community-membership) | Maintainer roles do not match governance docs |
| Decision-making | Partial | [groups](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/GOVERNANCE.md#community-groups) | Extensive docs on the various committees. However, practices around, say approving PRs/features/roadmap not documented. |
| Code and Docs Ownership | Partial | [owners](https://github.com/kubeedge/kubeedge/blob/master/OWNERS) | KubeEdge uses Prow, but needs to document how this works for contributors |
| Security Reporting and response | Partial | [team security](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/team-security/SECURITY.md) | A security process exists, but is not findable from base repos, project homepage, or other docs.  Also no clear process for replacing security team members. |
| Communication and Meetings | Complete | [meetings](https://github.com/kubeedge/kubeedge/tree/58bf767f8b763f9e77cf237b9488adfcc8b601be?tab=readme-ov-file#contact) | multiple types of meetings defined, seem regular and well-attended. Notes/videos could be better, but that's everyone's struggle |

#### Sub-projects, plugins, and related

The project includes the following sub-projects, plugins, and other notable divisions:

| Area | Ownership and Operation | Standing Bodies | Project Alignment | Notes |
|:-----|:-----------------------:|:---------------:|:------------------|:---|
| SIG AI | Complete | Complete | Complete | |
| SIG Device IOT | Complete | Complete | Complete | |
| SIG MEC | Partial | Missing | Partial | Not set up yet? |
| SIG Network | Complete | Complete | Complete | |
| SIG Node | Partial | Partial | Partial | No chairs, meetings |
| SIG Release | Partial | Partial | Partial | No real meetings or docs |
| SIG Robotics | Complete | Complete | Complete | |
| SIG Scalability | Partial | Partial | Complete | Not fully staffed |
| SIG Security/Security Team | Partial | Partial | Partial | Two groups are not reconciled, fully staffed |
| SIG Testing | Partial | Partial | Partial | |

The SIG charters do not identify if any repositories are owned by particular SIGs.

### Operation

#### Transparency and freshness

The project has extensive governance documentation which attempts to define all aspects of governance for the project clearly for contributors and the public. Much of this textual documentation is recently updated, within the last 6-8 months and there is evidence of a sincere effort to keep it up to date.

A lot of project decision-making seems to happen at the frequent and well-attended community and SIG meetings. However, these meetings do not have good notetaking, and the video recordings are not up to date. This means that project members who cannot directly attend the meetings may be left out of decision making.

How PRs (and roadmap items) get approved is also not well-defined. KubeEdge uses Prow but does not have docs for the approval process or explain Prow to contributors. Clearly the project has an efficient process, because PRs are handled and closed or merged quickly, so this seems like it's just a matter of writing down existing practices.

#### Governance Drift

Governance Drift can occur when the executed and observable governance of a project deviates from the documented governance of the project.

Because of the overhaul of project governance and the institution of the TSC, there is currently governance drift in terms of actual leadership structures not yet matching statutory ones. See Evolution below.

#### Ownership

The project's ownership evaluation did not leverage Sheriff, the CNCF GitHub permission auditing tool.

KubeEdge uses Prow with OWNERS files in all repos. These OWNERs files seem to mostly match the expressed leadership of the project, although the current governance transition makes that hard to tell. It's also not clear where a specific SIG should be the owners of a repository.

KubeEdge does not use Sheriff or Peribolos in order to enforce community GitHub-level permissions. Since they're already on Prow, Peribolos might be an easier implementation.

### Maintainer List(s)

The project's maintainer list(s) are in transition, per Evolution below. This makes it difficult to currently assess the updated state of the maintainer list. The definition of Core Maintainer is also unclear, as mentioned elsewhere.

Both [old](https://github.com/kubeedge/kubeedge/blob/86f768b89dd084ff913014813c2da4dfa33aa8f2/MAINTAINERS.md) and [new](https://github.com/kubeedge/community/tree/f3548585203cd39e0675836bf526087807091d81/committee-technical-steering#members) maintainer lists have been updated in the last year. Both reflect a diverse pool of employers. All of the members of the transitional TSC are contributors who have been recently active in the project. We did not assess the Core Maintainers because it is unclear whether they are supposed to be current.

Further, the project has a clear practice of maintainer turnover. In the 3 years of the project, they have added six maintainers and retired three.

### Evolution

The KubeEdge project has very recently (within the last 3 months) started transitioning to a new governance model headed by an elected Technical Steering Committee. They've also implemented multiple new SIGs. This shows progressive maturation on the part of the project. The Governance WG will be working with the project to help them implement the new structure, particularly the elections.

This also creates the primary critical governance issue: the transition between governance models is not complete, or at least the documentation of it is not complete. Both the old (core maintainers) and the new (TSC) leadership structures still exist in the the project currently. It's not explained how the transition will get completed.  Will the Core Maintainers be dissolved? If they won't, where is the documentation on that team?

Making sure that all of the SIGs have appropriate staffing is an additional evolution.

### Governance Findings Table

| Finding Title | Importance | Description | Links | Notes & Impact |
|:------------- |:----------:|:------------|:------|:---------------|
| Governance Transition | Critical | Need to complete transition to new governance, or define the process more clearly | [governance](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/GOVERNANCE.md) | Unclear which parts of old governance are going away |
| Core Maintainers Undefined | Critical | Core maintainers exist, but are undefined in the project governance | [maintainers](https://github.com/kubeedge/kubeedge/blob/86f768b89dd084ff913014813c2da4dfa33aa8f2/MAINTAINERS.md) |  |
| Security Team | Critical | Unclear split between Security Team/SIG Security | [team security](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/team-security/SECURITY.md) | Staffing/replacement also not documented |
| SIG vs. Project Roles | Low | Should define which contributor ladder roles are per-SIG | [membership](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/community-membership.md) | |
| Lots of senior roles | Low | 5 different classes of senior roles may be too large for project | [membership](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/community-membership.md), [governance](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/GOVERNANCE.md) | |
| Chinese translation | Low | Translate governance docs to Chinese for accessibility | [governance](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/GOVERNANCE.md) | |
| Links between repos | Low | Link to governance/community repo from READMEs in other repos | [README](https://github.com/kubeedge/kubeedge/blob/master/README.md) | |
| Need CoCC practice | Med | Directs folks to report CoC incidents to kubeedge@gmail.com, but unclear who that is or if they have CoCC training | [Conduct](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/CODE_OF_CONDUCT.md) | Contact CNCF CoCC about setting up handling reports. |
| Bare-bones contributor guide | Med | Contributor guide is insufficient for project complexity | [contribute](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/contribute.md) | New contributors cannot self-start |
| Reconcile Ladder | Med | Contributor membership roles need to be reconciled with the actual roles people hold | [membership](https://github.com/kubeedge/community/blob/f3548585203cd39e0675836bf526087807091d81/community-membership.md#kubeedge-community-membership) | List of roles there doesn't match lists of leadership elsewhere |
| PR Process | Low | Document PR/roadmap approval requirements/process | | |
| Meeting Notes | Low | Take better meeting notes for reference | [agenda](https://docs.google.com/document/d/1Sr5QS_Z04uPfRbA7PrXr3aPwCRpx7EtsyHq7mp6CnHs/edit) | allows async participation |
| SIG Ownership | Low | Document if repos are owned by SIGs | [Special Interest Groups](https://github.com/kubeedge/community/tree/f3548585203cd39e0675836bf526087807091d81) | |

### Previous Reviews

| Date   | Requested By  |                   Reason                   | Link                 |
|:-------|:--------------|:------------------------------------------:|:---------------------|
| *Date* | *TOC/Project* | *Maturity change / project request / etc.* | *link to review doc* |
