# WASMEdge Governance Review

What follows is a governance review and assessment for the WASMEdge project. This review is carried out by members of the Governance Working Group of TAG Contributor Strategy. The review may have been done because of a change in maturity level for the project, at the request of the TOC, or as a request by the project itself. If requested by the project, the review will be provided to the project maintainers. Otherwise, the review will be submitted to the TOC for their follow-up.

Projects may ask TAG Contributor Strategy for assistance in resolving any issues uncovered by the review. The TAG is available via our [slack channel](https://cloud-native.slack.com/archives/CT6CWS1JN), [email](https://lists.cncf.io/g/cncf-tag-contributor-strategy), [GitHub](https://github.com/cncf/tag-contributor-strategy), or by joining our weekly meetings (listed on the [CNCF public calendar](https://www.cncf.io/calendar/)).

## Summary and Assessment

Status: Mostly Satisfactory

WASMEdge has clearly made progress in all aspects of governance and contributor management since joining the CNCF. They have many miscellaneous issues with governance and contributor documentation, which is normal for a project at this stage.  The project needs to use its advancement to Incubating in order to drive more contributor recruitment.

### Executing the Assessment

- WASMEdge requested a Governance Review for their Incubating application in [August 2024](https://github.com/cncf/tag-contributor-strategy/issues/690)
- At Kubecon NA 2024, Josh Berkus met with project leads to discuss the governance review and good practices for projects.  As a result of this meeting, the project made several improvements.
- Josh Berkus began the review on February 5, 2025, and completed the first draft on February 14.

All references to WASMEdge documentation and repositories should be considered current of early February 2025, and may have changed by the time you read this.

### Must-Fix Items

The following issues have been identified that need to be resolved before advancing to Incubating:

No issues were found that would be a blocker to Incubating status.

### Points of Excellence

The following aspects of governance are exemplary, and can be referenced as examples for other projects to copy:

* The project has done a good job at using the intermediate levels in its contributor ladder to advance contributors, and involving them in the PR process.

### Areas for Improvement

Over the next year, the project should work on the following issues to improve its governance, these are considered non-blocking:

Priority items:

* Re-focus on new contributor recruitment, possibly via mentorships or other means.
* Work on completing the Contributor Guide so that it has sufficient detail for self-guided contributor entry.
* Mentor one or more Committers so that they can advance to Maintainer.

Miscellaneous issues:

* Remove the contributor ladder sections from GOVERNANCE.md, as they duplicate content in CONTRIBUTOR_LADDER.md and may conflict confusingly.
* Fix broken links in GOVERNANCE.md
* Work with the folks in the Committer tier to broaden their knowledge of the project, with the idea of getting them to Maintainer status.
* Move the licensing reminder/requirements from the Code of Conduct file to the Contributing guide.
* Update the Code of Conduct with links to the CNCF CoCC (for escalation) as well as your own team.
* Add links to governance and contributor documentation from Readme and main project documentation or website.
* Ensure that all items on the Roadmap are linked to descriptions of features or activities elsewhere.  Consider adopting a project board or milestone system, which would probably be easier to maintain.
* Once the English-language governance is stable, the project should consider translating all governance documents into Chinese in order to support that community.
* Remove SecondState links from website footer.
* Work on mentoring one or more Reviewers and Committers to the point of advancing to Maintainer before Graduation.
* Add information about the Code of Conduct to the Contributor Guide.

## Review

The following review primarily consists of an audit on the project's self-assessment in their Graduation application.

[Project Application with Governance and Community Sections](https://github.com/cncf/toc/issues/1316)

### Governance Summary

WASMEdge is set up as a simple [Maintainer Council](https://github.com/cncf/project-template/blob/main/GOVERNANCE-maintainer.md) style governance based on the CNCF templates.  Currently there are four maintainers.

### Governance Evolution

WASMEdge has evolved project governance as the project has matured.

* WASMEdge adopted the Helm project governance at founding.
* WASMEdge project members met with Josh Berkus from Governance WG at Kubecon NA 2024.  Based on feedback from that meeting, the project members revised their project governance to be clearer, more complete, and rebased it on CNCF templates.  They also added a detailed contributor ladder, and assigned members of the project to the appropriate roles within the contributor ladder.

### Discoverability

* Clear and discoverable project governance documentation.

Discoverability: The project's governance and contributor documentation is all together in [one directory in WASMEdge's main repository](https://github.com/WasmEdge/WasmEdge/blob/master/docs/CODE_OF_CONDUCT.md), which is excellent.  However, that folder can be hard to find; it's not linked from the repository's README, nor is it linked from the project website or main documentation.

Clarity: Aside from a few issues (in Improvements above), there's a clear layout of files and governance documentation seems to cover most requirements, roles, and contingencies in clear language.  The one caveat is that at least several links between governance documents are broken; a link cleanup would be a good idea.  As the contributor base for the project includes many Chinese developers, the project could consider offering governance documentation in both languages.

### Accuracy and Clarity

* Governance is up to date with actual project activities, including any meetings, elections, leadership, or approval processes.

Most governance documents have been updated at least once within the last 3 months. The Governance was substantially updated 2 months ago (see Evolution), which means that some parts cannot be assessed yet.  The project immediately promoted multiple contributors to the new roles they added in their Contributor Ladder, showing a strong intention to make use of the Ladder.  Non-maintainer reviewers and "Committers" appear to be fairly involved with the project and with the review process, more so than most small projects.

The [document-based Roadmap](https://github.com/WasmEdge/WasmEdge/blob/master/docs/ROADMAP.md) appears to be regularly used and updated to reflect project work.  However, many of the items on the Roadmap do not link to issues, PRs, project cards, or other documents that would allow users or contributors to understand what each roadmap item represents.

* Governance clearly documents [vendor-neutrality](https://contribute.cncf.io/maintainers/community/vendor-neutrality/) of project direction.

All governance, contributor documentation, website and other resources are written in a vendor-neutral way; SecondState is not mentioned as being authoritative or involved in any decisions.  Observable decisions and operations within the community appear to operate entirely according to community rules.  Neither the mailing list nor social media are used much, which also means that they aren't used for vendor content.

The main project website has several links to SecondState in the website footer which should be removed or changed to be more vendor-neutral.

### Decisions and Role Assignments

* Document how the project makes decisions on leadership roles, contribution acceptance, requests to the CNCF, and changes to governance or project goals.
* Document how role, function-based members, or sub-teams are assigned, onboarded, and removed for specific teams (example: Security Response Committee).

Project documentation covers all required lifecycle areas for a small project.  See the [Governance Review request](https://github.com/cncf/tag-contributor-strategy/issues/690) for some examples by the project of management activities.

### Maintainers and Maintainer Lifecycle

* Document complete list of current maintainers, including names, contact information, domain of responsibility, and affiliation.
* A number of active maintainers which is appropriate to the size and scope of the project.

<!--- Check maintainers.md, governance.md, contributor ladder and other files.
Maintainers file should have contact info (not just GH handles), other useful information, and employer
Do a quick sanity check on the number of maintainers.  A very large critical project applying for graduation which has three maintainers is probably at bus-factor risk.  In contrast, a narrowly-scoped project with 50 maintainers is probably listing people who are not actually maintainers.
Also check that maintainers on the list are active using Devstats, GitHub and LFX Insights.  Query inactive maintainers. --->

Currently WASMEdge has [four Maintainers](https://github.com/WasmEdge/WasmEdge/blob/master/docs/OWNER.md), which seems reasonable for a project this size.  They are also the foudning maintainers of WASMEdge, and there has yet to be any maintainer turnover.  All are active. The project has promoted many regular contributors to intermediate levels of code ownership (Reviewer and Committer), and seems prepared to eventually advance one or more contributors to maintainer according to the documented requiremens.

All four current Maintainers work for SecondState, but several Committers and Reviewers are community contributors.

* Document a complete maintainer lifecycle process (including roles, onboarding, offboarding, and emeritus status).
* Demonstrate usage of the maintainer lifecycle with outcomes, either through the addition or replacement of maintainers as project events have required.

Maintainer qualifications and responsibilities are clearly documented in the Contributor Ladder.  As mentioned above, the project has not yet had any new maintainers recruited or old ones retire.

* Project maintainers from at least 2 organizations that demonstrates survivability.

WASMEdge does not yet meet this requirement.

### Ownership

* Code and Doc ownership in Github and elsewhere matches documented governance roles.

WASMEdge uses [CodeOwners](https://github.com/WasmEdge/WasmEdge/blob/master/.github/CODEOWNERS) which appears to show distributed ownership of code, where ownership is assigned to individuals with official community Roles.

### Code of Conduct

* Document adoption of the CNCF Code of Conduct
* CNCF Code of Conduct is cross-linked from other governance documents.

WASMEdge has adopted the CNCF CoC.  Most other governance documents, including processes for role removal, reference the Code of Conduct.  The Contributor Guide does not, however.

The project handles its own initial CoC reports, with an escalation path to the CNCF CoCC.  They should add a link to the CNCF CoCC in their copy of the CoC, for reporters who wish to file a report concerning project bias or similar issues.

The project added a section to their [Code of Conduct](https://github.com/WasmEdge/WasmEdge/blob/master/docs/CODE_OF_CONDUCT.md) which specifies licensing requirements.  While this notice is important, it belongs in the Contributor Guide and not in the Code of Conduct.

### Subprojects

* All subprojects, if any, are listed.
* If the project has subprojects: subproject leadership, contribution, maturity status documented, including add/remove process.

While the WASMEdge project has several repositories, none of them seem to be identifiable subprojects.

### Contributors and Community

* Contributor ladder with multiple roles for contributors.

WASMedge has a fairly complete [Contributor Ladder](https://github.com/WasmEdge/WasmEdge/blob/master/docs/CONTRIBUTOR_LADDER.md), Identifying four escalating levels of responsibility with defined requirements.  They should remove the duplicate contributor ladder sections from the Governance file.

* Clearly defined and discoverable process to submit issues or changes.

WASMEdge has a Contributing Guide which is currently a work in progress.  Several parts of contributing are well-defined but other parts are stubs.  This includes some general information about issues and PRs.  Their primary repository has multiple issue templates for different kinds of reports.  This seems to be working; they have [100 different issue reporters](https://wasmedge.devstats.cncf.io/d/9/developer-activity-counts-by-repository-group-table?orgId=1&var-period_name=Last%20year&var-metric=issues&var-repogroup_name=All&var-country_name=All) in the last year, and [45 single-PR submitters](https://wasmedge.devstats.cncf.io/d/9/developer-activity-counts-by-repository-group-table?orgId=1&var-period_name=Last%20year&var-metric=prs&var-repogroup_name=All&var-country_name=All).

The [Roadmap](https://github.com/WasmEdge/WasmEdge/blob/master/docs/ROADMAP.md) has a written process for adding items to it, and as far as I can tell the project has followed this public process for the last few quarters.

* Project must have, and document, at least one public communications channel for users and/or contributors.
* List and document all project communication channels, including subprojects (mail list/slack/etc.).  List any non-public communications channels and what their special purpose is.
* Up-to-date public meeting schedulers and/or integration with CNCF calendar.

The project has:

- [mailing list](https://groups.google.com/g/wasmedge/): rarely used
- [Discord](https://discord.com/invite/JHxMj9EQbA): very active
- [community meeting](https://docs.google.com/document/d/1iFlVl7R97Lze4RDykzElJGDjjWYDlkI8Rhf8g4dQ5Rk/edit?tab=t.0:) held regularly, videos uploaded
- Slack channel on CNCF Slack: not very active

* Documentation of how to contribute, with increasing detail as the project matures.

WASMEdge's [contributor guide](https://wasmedge.org/docs/contribute) is a work-in-progress, with some parts being fairly complete (how to build from source) but many others being stubs (testing guide) and many being fairly generic templates without a lot of specific project information (release process).  This guide is below average for an Incubating project, and is an area the project should focus on in the next year.

* Demonstrate contributor activity and recruitment.

WASMEdge has a steady flow of [drive-through contributors](https://wasmedge.devstats.cncf.io/d/14/new-and-episodic-pr-contributors?orgId=1&var-period=w&var-repogroup_name=All&from=now-2y&to=now-1M) which says good things about its accessibility.  However, the number of casual contributors is not growing, but rather stuck at around 1-2 contributors per week.  The [number of overall contributors](https://wasmedge.devstats.cncf.io/d/74/contributions-chart?orgId=1&var-period=m&var-metric=contributions&var-repogroup_name=All&var-country_name=All&var-company_name=All&var-company=all&from=now-3y&to=now-1m) is not growing either, and seems to have peaked in the 30-50 range after doubling in the first year of the project. While 30-50 contributors is fine for an Incubating project, it should a clear area of future focus for the project on contributor recruitment and retention.

The project is aware of this and has been participating in contributor recruitment activities, such as LFX mentorships.  As noted, they've also worked hard on advancing some of their existing contributors to greater responsibility.
