---
title: "Best practices when interviewing a deaf or hard of hearing individuals (media interviews)"
date: 2024-02-20
description: >
  Tips when doing media interviews with deaf or hard of hearing individuals
---

Accommodation needs will depend on the interviewee. Deaf individuals may use sign language or speak and lip-read, while hard of hearing interviewees hear but also rely on additional cues (e.g., lip-reading, captions). In-person or virtual interviews and podcasts present different opportunities and challenges, so please be sure to read through all relevant sections. 

## 1. Interviewing a deaf individual through an interpreter

### 1.1. Info for production team 

**Extended Interviews (30+ minutes)**: You'll need two interpreters for any interview longer than 30 minutes. Interpreting requires a high degree of concentration, and regular breaks are needed to ensure accuracy and interpreter well-being.

**Allow for 15 to 30 min prep time**: If the interviewee and interpreter have not worked with each other before, provide time for them to connect prior to the interview. The deaf interviewee will need time to communicate their preferences and ask about specific details.

**Accessibility for recorded content**: When creating video content, including social media, be mindful of banner placement so they don't obstruct the signing area or the interpreter. Additionally, including closed captions for videos and podcast transcripts makes valuable information accessible to a broader audience.

### 1.2. Info for interviewer

**Clarity and repetition**: Don't shy away from repeating questions or asking for clarification if needed. (American) Sign Language and English are distinct languages, each with their own grammar. Additionally, the interpreter is not a subject matter expert, so misunderstandings may occur.  

**Speak directly to the interviewee**: Talk to the interviewee directly ("What are *your* thoughts on…"), don't ask the interpreter to ask them something ("Can you *ask them* if….").

**Don't talk to the interpreter directly**: During the interview, the interpreter is voicing the deaf interviewee. They are not part of the conversation, so don't include them unless you mean to interview them as well. You may thank them at the end, but bear in mind that they will be interpreting your "thank you" and may be unable to respond.

### 1.3. Info for interpreter 

**Ask for clarification if needed**: If the interpreter doesn't understand what the interviewer or interviewee says, they should ask for clarification. Some interpreters fear it might interrupt the flow. However, not asking for clarification will lead to miscommunication, potentially disrupting the rest of the interview. Open communication fosters a smooth interview experience. Please don't hesitate to mention concerns about interpreting speed or anything hindering clarity. 

## 2. Interviewing a non-signing deaf, oral, or hard of hearing individual  

### 2.1. Info for production team

**Provide written details in advance**: If possible, send a list of topics to be discussed during the interview ahead of time. This allows the interviewee to prepare and reduces anxiety around misunderstanding questions on the spot. It also ensures they can fully engage in the conversation.

**Quick "warm-up" meeting**: Not only does it help break the ice, it also allows lip reading interviewees to familiarize themselves with the interviewer's lip patterns. And those using speech-to-text apps can test the app's accuracy against the interviewer’s speech.

**Audio accessibility**: Before the interview, inquire if the individual uses any personal assistive listening devices (ALDs), such as amplified headphones or personal amplifiers. If so, ensure compatibility with the interview setting, offer assistance with setup, and offer a microphone. 

### 2.2. Info for interviewer 

**Speak slowly and clearly**: There is no need to speak louder when the interviewee has trouble hearing you. Instead, focus on speaking slowly and clearly at a normal volume. Raised voices can cause distortion, making it even harder to understand.  While you should speak clearly, don't over-exaggerate your mouth movements as it might confuse the interviewee. Just focus on slowly pronouncing each word. If the interviewee still doesn't understand, try rephrasing the sentence.  

While some deaf individuals lip-read, not all rely on it. Ensure clear facial visibility and avoid jargon or fast speech.

## 3. In-person vs. virtual vs. podcast

### 3.1. In-person interview with an interpreter

#### Info for the production team

**Sit interpreter next to interviewer**: In video interviews where the interpreter is on screen, sit the interpreter next to the interviewer. That way, when you speak, your interviewee can see both of you, and when they speak, it's easier for you to focus on them vs the interpreter ([here is a great example](https://www.youtube.com/watch?v=3fYd5vQFWw8)).

**Interpreters off camera**: You may also keep interpreters off camera. In that case, try to place the interpreter behind you so interviewees can see you and the interpreter at the same time. 

**Multiple deaf interviewees**: Adjust interpreter arrangements based on the number of individuals to manage communication demands effectively. 

**Mobility and signing space**: Allocate adequate space to move comfortably without the risk of interfering with equipment.

#### Info for interviewer 

**Look at the interviewee**: Interpreters are voicing the interviewee, but you are talking to the deaf individual, so please be sure to speak directly to and look at them while they are speaking. While it's tempting to look at the interpreter, it may come across as rude. Of course, you may look at the interpreter if they are asking you directly to repeat your last statement/question. 

### 3.2. In-person interview with non-signing/oral deaf or hard of hearing individual 

**Face each other in a bright room**: Deaf non-signing and hard of hearing individuals may rely on lip reading, so be sure they can clearly see the interviewer. Select a room with good lighting.

**Reliable internet connectivity**: Interviewees relying on speech-to-text apps for real-time transcriptions will need a good and reliable internet connection.  

### 3.3. Virtual Interviews

#### Info for production team

**Enable captions**: Activate captions beforehand. Most video conferencing tools, such as Zoom and Google Hangouts, offer auto-captioning services at no extra cost. Unfortunately, captions must often be enabled in the settings before the meeting starts, so be sure to do that beforehand. For interviewees who are hard of hearing, captions can significantly help  follow the conversation. 

**Ensure interviewers are visible**: Deaf non-signing and hard of hearing individuals often rely on lip reading. Ensure the interviewer's camera is on and their mouth clearly visible. This helps fill any gaps in audio communication. 

#### Info for interviewer 

**Enable captions**: We recommend the interviewer also enable captions on their end. That way, they can see if they are working properly and that what they are saying is clear.

### 3.4. Podcast with an interpreter 

#### Info for production team

**Microphone**: Equip the interpreter with a microphone, not the deaf signing individual.

#### Info for Interviewer

**Live introductions**: When you introduce the interviewee, state that they are deaf and will be voiced by an interpreter. 

**Repeat that an interpreter is voicing a deaf interviewee**: For longer-form interviews, repeat that an interpreter is voicing the interviewee. Some people might have missed the beginning and be unaware that it’s not the voice of the person speaking (e.g., "For those who have joined late, we are talking to Jamie Smith, a deaf engineer at Acme, and a sign language interpreter is voicing her.") 

### 3.5. Podcast with non-signing oral deaf or hard of hearing individual 

#### Info for production team and interviewer 

**Tone of voice**: Plan some time for recording tests, and don't hesitate to say if the interviewee's voice is unclear, too loud or too low, or if words are mispronounced. Remember, they can't hear themselves (well) and will appreciate your guidance. They too want the outcome to be great. 

Also, note that natural fluctuations in vocal volume may occur. Your patience and understanding are appreciated.
