---
title: "Best practices for an inclusive and welcoming conference"
linkTitle: "Inclusive conference best practices"
date: 2023-10-01
description: >
  This is a living document, so please be sure to check regularly for updates.
---

Understanding the unique needs and preferences of deaf and hard of hearing (deaf/hoh) individuals is crucial in creating an inclusive and accessible conference experience. This guide is specifically designed to assist you in this process, ensuring that your event is not only welcoming and accommodating, but also tailored to enable deaf and hard of hearing attendees to actively participate and enjoy a fulfilling experience.

The first step of being more inclusive is understanding that deaf/hoh are not a one-size-fits-all group. We have different needs and preferences, so it is important to provide multiple options for deaf/hoh attendees. If we can't fully participate, we will likely not return, reinforcing the vicious cycle of deaf/hoh individuals not attending conferences.  

Early planning is key to accommodating the accessibility needs of attendees, speakers, and sponsors. We recommend providing them the opportunity to specify their needs as early as possible, allowing you to plan for them in advance. Use your website, registration, and call for papers forms to gather this information early. Often, conference organizers don't budget for accessibility until a request is made, which can lead to uncomfortable situations. Remember, accessibility is rarely a static budget line item, and it can be challenging, especially when planning it for the first time.  

To make the process as straightforward as possible, we've created this **[DHH Accessbile Conference Checklist](https://docs.google.com/spreadsheets/d/1lC1woVTu8YNWykCJ2FwBgy3aJEWbVUP0cZT3-Nw1hj0/edit#gid=0)**. Make your copy to use it for your event. While the checklist provides a meticulous list of action items, this detailed document provides the context to understand the "how" and "why" behind them. We also included alternatives if a particular accommodation isn't feasible. 

**Getting started can feel overwhelming**. But consider this: Conferences haven't historically been accessible, so we don't expect deaf and hard to hearing individuals to attend in droves — you'll have time to learn on the go. **Start with the first four items** on the [checklist](https://docs.google.com/spreadsheets/d/1lC1woVTu8YNWykCJ2FwBgy3aJEWbVUP0cZT3-Nw1hj0/edit#gid=0): secure a budget to be prepared and clearly state that you'll provide accommodations per request, and see whos interested. It will probably take some time until the word gets out that your conference is deaf and hard of hearing accessible. Note that on-screen captions should ideally be provided either way, as their usefulness goes far beyond our community. 

If you have any questions, please get in touch with us at cncf-tag-contributor-strategy@lists.cncf.io — we'd love to help you make your event more accessible! 

**Note**: This document is open source. If we missed anything, please submit a pull request or issue so we can update it — thank you! 

<div class="section-group">
{{% blocks/section color="gray-300" %}}
  <h3>Get your Accessbile Conference Checklist</h3>
  <p>To make it really easy, we've captured everything in this document in an event checklist.</p>
    <a class="cncf-button-primary" href="https://docs.google.com/spreadsheets/d/1lC1woVTu8YNWykCJ2FwBgy3aJEWbVUP0cZT3-Nw1hj0/edit#gid=0">
    Download Checklist
    </a>
{{% /blocks/section %}}
</div>

## General information

### DEIA: Diversity + Equity + Inclusion + Accessibility

We encourage you to include the A in your DEI efforts: **Diversity + Equity + Inclusion + Accessibility (DEIA)** — too often our community _is_ an afterthought. We want to change that and need your support!

#### Disabilities coordinator

We recommend appointing a designated disabilities coordinator to handle any prompt communications involving accommodations before and during the conference. This includes communication with attendees, speakers, facilities, and other event organizers. For signing attendees specifically, the coordinator typically:
- Facilitates communications between interpreters, assigns them to deaf attendees and location, solicits feedback, and determines the fit (e.g., some deaf people may not feel comfortable with the interpreter's signing style, clarity, or quality).
- Ensures proper lighting and interpreter staging.
- Provides extra equipment in case of failures, such as lights, stands, chairs, etc.
- Takes attendee feedback on interpreters

#### Be ADA-compliant (whether US-based or not)

People with disabilities in the US fought long and hard to get the [Americans with Disabilities Act (ADA)](https://www.ada.gov/) passed. If your country doesn't have a counterpart law, we encourage you to use ADA as a reference point. But even in the US, although nearly all buildings are ADA-compliant, we often see a gap at conferences: risers/stages generally don’t have ramps, making them inaccessible for people with physical disabilities (the law does not yet apply to events, unfortunately). Carpets make it harder for wheelchair users, physically and battery draining. Provide assistance when asked and have charging stations available.

### Sign Language

Sign language is not universal — there are 24 country-specific sign languages in the EU alone. 

While English serves as a primary business language, there is no established primary business sign language. English-speaking countries, for instance, have different sign languages, including American Sign Language (ASL), British Sign Language (BSL), New Zealand Sign Language (NZSL), or Auslan (used in Australia). 

However, there is International Sign (Language), or IS, an "artificial" sign language developed to communicate across borders. While it is used by international organizations such as the World Deaf Federation, Deaflympics, and EU and UN events, it's not widely known among deaf individuals not involved with these organizations. 

#### Which sign language should you use?

While the sign language choice for North American conferences is clear (ASL), it's complicated for European international conferences. 
The World Deaf Federation uses IS and the host country-specific sign language at their events. If you expect to have a majority of host country-specific signing attendees at your conference, we recommend that same approach. 

For KubeCon Europe, we recommend two main sign languages: International Sign (IS) as the primary language and American Sign Language (ASL) as secondary. Keynotes should be signed in IS (interpreters on screen), while interpreters for attendees would sign in whichever language they chose. 

If you need to fly interpreters in (from other countries), consider hiring the attendee's preferred interpreters. Note that hourly rates might vary significantly depending on where interpreters are based. In some cases, flying in an interpreter might be more cost-effective than hiring one from the host country. So keep those options in mind as you plan for the event.

#### Working with interpreter agencies and freelancers 

Interpreters are often told by their agency that to behave professionally, they shouldn't wear comfortable/casual clothes or eat in front of their clients, etc. We disagree. In fact, it often creates an unnatural and stiff environment. We want our interpreters to feel comfortable.

A more relaxed and natural environment is especially important when interpreters are facilitating networking. We want interpreters to have a great experience as well! 

We recommend providing the agency or freelancers with the following guidelines:
- Feel free to wear comfortable walking shoes — there is a lot of standing. It's a tech conference, and most people dress casually, so you can, too.
- Help yourself with food and drinks provided by the conference as needed — you'll need the energy.

#### Sign language interpreters

Why do you need sign language interpreters if you have captions? First, captions are only available for talks. But what if the attendee wants to ask a question? Besides, most people go to conferences to network, not purely to hear talks they can watch on YouTube later. In fact, networking is where interpreters are most valuable (provided you have captions on screen). Learn more about the importance of networking for deaf/hoh below. 

It will be extremely difficult—if not impossible—to find interpreters who can interpret sessions accurately at highly technical conferences such as KubeCon. We recommend providing an accurate captions tool displayed on the screen while focusing interpreter support on Q&A and networking.  

However, some deaf signing members strongly favor interpreters at sessions. Here's one account from one of our members:

> "ASL is my first (natural) language, and if I have the choice, I will always choose interpreters over captions. Relying only on captions often leads to a cognitive overload for me. Words are conveyed, but I'm trying to process the information while looking at the speaker, which can be draining and hard. Good interpreters capture the spirit of the speaker and help me feel more engaged. I have been in meetings where only captions were available, meetings where there were interpreters present without captions, and both. Personally, I like having both because I can catch some technical words while feeling more engaged with the speaker."

Provide interpreters upon request and in advance. We also recommend having two sign language interpreters on-call to accommodate last-minute registrants or miscommunications. Ask interpreter agencies about their cancellation policies — these can vary significantly. A week’s notice, 48, or even 24 hours with a fee, are all possible, depending on the agency.

Obviously, a big conference like KubeCon has more resources than a local community event — we get that. Since we also want to be included in smaller events, we’ll offer various options. To be clear, the more cost-effective options aren’t as inclusive, meaning we’ll miss out on many opportunities our hearing peers benefit from. Opt for the more cost-effective route only if there is no alternative that provides accessibility. We deserve to be included and appreciate your support.

For deaf signing members, sign language interpreters are the most valuable but also the most expensive accommodation. Incorporate the cost into the overall conference cost. It should be no different than including audio/video equipment, swag, food, refreshments, etc. into your budget.

**Note:** The Linux Foundation is building its own team of freelance interpreters. If you are looking for interpreters for your tech conferences, let us know, and we can make recommendations. 

#### Include interpreters in recording

If you record your sessions, be sure the interpreters are on screen so deaf attendees can benefit from your accessibility effort even when watching them on-demand.

### Captions

There is no need to provide interpreters for every session, but captions should be available for all sessions. While there are many live caption software options, not all work well. Using a tool with low accuracy can be very confusing for deaf/hoh individuals, so select one that has been proven to work effectively.

Some caption tools work only for virtual events, others for in-person and virtual events.

#### Some considerations

Captions at the bottom of the screen are not visible unless attendees are sitting at the front. Consider adding them at the top. If that isn't feasible,  you might want to place the screen higher to ensure people in the back can also read them. 

Not everyone feels comfortable sitting at the front, but captions are only visible from the front. This goes back to the "please add captions at the top" recommendation. 

<img width="906" alt="Captions on top vs bottom of screen" src="https://github.com/cncf/tag-contributor-strategy/assets/74001907/b8a08ec0-162b-4465-84d5-a082ed078154">

*Captions at the top of the screen vs. captions at the bottom are truly accessible.*

Some captions are highly **accurate but lag** significantly. That creates a disconnect between the message received and the speaker/audience (not syncing with body language, laughter, etc.), which can create a feeling of ‘missing out.’

Unlike hearing people, deaf/hoh individuals can only focus on the captions or look at the speaker/slides (e.g., a technical graphic). So if they do look away, they will miss what's said. Hence, leaving content on the screen longer by **adding more than one line** will help people who rely on captions. 

Every session should have captions in the main conference language **on the screen by default** (vs. captions available on the phone). Reading captions on-screen makes attendees feel more engaged than looking at their phones (speakers might think they aren't interested). With a phone, attendees are constantly required to shift focus between their phones and speaker(s) and will miss parts of the message. This is even more critical when there are live demos because, to understand what is going on, attendees must see what's on-screen and read captions at the same time. Captions on the phone make that impossible. 

#### Captions use cases beyond deaf/hoh

Some attendees can hear but may be neurodivergent ( e.g., on the autism spectrum, with ADHD, and more) and have a hard time processing auditory cues — captioning is incredibly beneficial for them, too. Additionally, non-native speakers who aren’t fluent will benefit from captions as well.

#### Considerations for hoh speakers

While automatic captions through slide decks effectively capture the speaker's dialogue, they do not capture audience questions. To ensure that all audio is included in the captions, please ensure a microphone is available for audience questions, or designate someone to repeat the questions into the speaker's microphone setup.

### Global or national conferences

If you only have a few deaf individuals attending, provide two interpreters per individual (they always come in tandem for engagements longer than one hour). Wherever the deaf person goes, they’ll follow. This will allow deaf individuals not only to attend sessions but also to network with their peers, walk the show floor, and talk with vendors. This is particularly important if they are the only or one of a few deaf people attending, as any interaction is contingent on the availability of an interpreter.

Of course, this approach doesn’t scale well. If you have more deaf attendees, you’ll need to share accommodations among more individuals.

### Regional/single-track conferences

At smaller or single-track conferences, sharing accommodations among speakers and attendees is easier. Provide live captions and a pair of sign language interpreters.

If your budget is tight, consider offering an accessibility sponsorship add-on and mention throughout the conference that interpreters are made possible thanks to that company. That will motivate them or other companies to participate next time.

### Local and community events

For local and community events where attendance is free or low-cost, we recommend offering an accessibility sponsorship add-on (see prior section) to try to have interpreters on site. If that doesn’t work, live captions are certainly the minimum you should offer. Be sure to let the deaf attendee know before the event that you couldn’t raise funds for interpreters and that only captioning will be provided. Also, offer a refund if desired.

You could also try to incentivize the employer of the deaf attendee to pay for the interpreters and offer to list them as an official event sponsor.

## Website, registration and CFP form, and program information

### Event website

On the registration and call for papers (CFP) pages, state that accommodations will be made for speakers and attendees with disabilities. Clearly and prominently stating that will make us feel welcome and motivate us to participate. Don't bury that important information in a registration form we might never see. Here's some suggested copy:

> Interested in attending or speaking but require special accommodations? Please inform us about your specific needs through the registration or CFP form, and we will make every effort to provide the necessary support. For accommodation-related questions, please reach out to [accommodations@yourevent.com](mailto:accommodations@yourevent.com).

Consider creating a dedicated email address (e.g., accommodations@) to signal you take this seriously.  

### Registration and CFP form

Include a field asking if accommodations are needed (yes/no) and a free-form text box to specify. Everyone's needs differ, and they're hard to discern from a fixed form/dropdown.

### Program Information

On the program page, include session accessibility information, such as whether captioning will be provided and in which language. Also, mention that interpreters will be available upon request if requested in advance, and specify which sign language (e.g., American Sign Language, International Sign Language, etc.).  

## Pre-conference best practices 

### Reach out to attendees/speakers before the event

* Set up notifications or monitor registration and CFP forms for accommodation needs and ask for clarification if needed.
* Connect attendees with sign language interpreters to ensure they understand communication needs and style.
* For dedicated interpreters (see the [sign language interpreters](#sign-language-interpreters) section), provide both sides with contact information to communicate directly during the event should they run late or if a meeting place changes.  

### Connect us with our peers

Provide a way for deaf and hard of hearing attendees, speakers, and people with other disabilities to connect for peer support and potentially pool resources (e.g., an event Slack channel).

### Promote accessibility sponsorship opportunities

To help expand accessibility options and cover costs, provide companies with accessibility sponsorship opportunities such as funding:
* Disabilities coordinator (a company could offer an employee to serve in this role in return for sponsorship benefits)
* Onsite interpreters (a company may already have interpreters who can attend the event and support accessibility)
* Captioning services
* Networking events
* Accessibility booth/area

## Day of best practices

### Venue walkthrough 

Offer a venue walkthrough before the event for deaf/hoh, attendees with other disabilities, and sign language interpreters to familiarize themselves with the layout, stage, and any potential obstacles. It's much harder for disabled folks to "glean" information about rooms, directions, and locations. Here are two voices from the community highlighting their personal experience:

> "I've missed so many important sessions because I ended up on the opposite side. Hearing folks can easily ask for directions and help each other. They can also talk while walking, which lip-readers like me can't."

> "As a physically disabled person, it would also be useful to receive a lot more details on the venue before the event. Usually, I have to completely redo my schedule after I navigate the venue on the first day because there are often access obstacles that aren't obvious on a map. A video walkthrough could be an alternative."


### Reserved seating at the front

Have some reserved seating at the front for deaf and hard of hearing attendees. Many rely on lip-reading, so you want to be sure they can see the speakers well. If speakers are wearing masks, it inhibits many deaf/hoh attendees from reading lips. Opt to provide speakers with clear masks if they prefer to wear a mask when speaking, or provide social distancing opportunities instead so they may speak maskless. 

Provide reserved chairs in the front row for deaf/hoh attendees. Leave two loose chairs at or near the stage area for sign language interpreters (even if just for Q&A support), and make sure the chairs are comfortable. Also, keep the front row clear to ensure there is space for them.

In particular, keynote rooms tend to be dark, with a bright spotlight on the stage. Consider adding frontal or overhead lighting in the interpreter seating area. Here's an anecdote from one attendee:

> "At one point during the keynote, one interpreter sat directly below another interpreter, shining a phone flashlight from below to improve visibility." 

### Accommodation desk

Set up an accommodation desk and/or communication channel where attendees can ask questions, request changes, or spontaneously get an interpreter, if available. Be sure to staff it with people familiar with deaf/hoh needs and have assistive technology available to assist with communication when needed.

### Deaf or hard of hearing speakers and panelists  

#### Provide attendees and speakers with prep time 

If speakers need interpreters or caption monitors, consider facilitating dry runs so deaf/hoh speakers and panelists can practice with their assigned interpreter and/or test the monitor setup. This will also allow speakers and interpreters to familiarize themselves with individual signing and speaking styles, ensuring smooth interpretation.

Introduce deaf/hoh speakers to sign language interpreters prior to the event. This will allow them to share materials (slides, speaker notes, etc.) with interpreters. Knowing what the talk is about will help provide much more accurate interpretation services. 

Signs for different technologies are not yet fully established (that is especially true in cloud native). Speakers and interpreters will need to agree on how to sign key terms and concepts. Agreeing on a shared vocabulary for on-stage communications will enhance communication efficiency.

If there are non-signing deaf or hard of hearing speakers, place a monitor visible from the stage so they can read the captions from fellow panelists and during Q&A. Note: captions on the screen facing the audience won't work in this case, they will need a monitor facing the speakers.
 
### Microphones for speakers and Q&A

Provide microphones for speakers and audience questions — even in small rooms. Hard of hearing attendees or speakers will struggle to hear the question without a microphone, and the captions tool won't be able to capture it either. If you can't provide a microphone for audience questions, have the speaker or someone else repeat the question in the microphone: "This person was asking …" 

### Meeting point area 

Especially at large conferences, if you have multiple deaf and hard of hearing attendees, create a meeting point area where deaf and hard of hearing attendees can find each other, meet with interpreters, and/or coordinate which session they will attend next if they share interpreters. 

## Conference networking opportunities

### Interpreters during networking sessions

One of the main reasons people go to conferences is to network. That is no different for deaf and hard of hearing attendees. Yet, most conferences only provide support during sessions, denying us this important event aspect. 

Networking is key for job opportunities, professional growth, and learning from peers. It is hard enough for people with disabilities to find or change jobs, making these networking events even more important. It is an important channel for professional growth and shouldn't be overlooked in your inclusion efforts. 

Having the opportunity to network with hearing peers is important not only for the individual but also helps break down prejudices and change attitudes toward us. These one-on-one connections are invaluable for fostering inclusion overall. So please be sure to allow your deaf and hard of hearing attendees and speakers to participate.

## Post-Show

**Video uploads**: Be sure to manually click ‘Auto Captions’ when uploading videos, as they will not become automatically available once they are transferred to a channel or platform.

**Post-event survey**: Include accessibility question(s) on any feedback survey.

Thank you for taking the time to review our best practice recommendations. We hope this was useful and that you'll be able to implement them at your next event. If your conference is accessible to our community, please be sure to add it to this [accessible tech conference list](https://docs.google.com/spreadsheets/d/1kQmhwQc45S6SC2fYsULue4our72TLH86kVD5KA0EC-4/edit#gid=0) so more people from our community find out about it.
