---
title: "How To Moderate An Open Source Meeting"
date: 2023-06-28
description: >
  A guide to open source meeting moderation.
---

## Introduction
Meeting moderation in the open source context plays a crucial role in fostering inclusivity and enhancing participation within communities. By implementing effective moderation practices, these communities can cultivate an environment that welcomes individuals from diverse backgrounds and encourages their active contribution of perspectives and ideas. 
Moderation accomplishes this by establishing a respectful and inclusive atmosphere, promoting equal participation, nurturing collaboration, managing disruptions, and fostering an environment where new contributors would feel comfortable to learn and ask questions. As a result, the moderator serves as a vital component in ensuring that open source meetings are inclusive, productive, and beneficial for all participants.

## Selecting a Moderator
Selecting a suitable moderator is of utmost importance in facilitating effective open source meetings. It is essential to choose an impartial individual who can oversee the proceedings and maintain a balanced discussion environment. A moderator is typically selected from the pool of regular attendees at the meeting. Ideally, the moderator should have demonstrated commitment to the group's work through their contributions and active participation. The moderation role should ideally be rotated among the regular contributors to ensure that the responsibility for directing the meetings is not solely carried by a few attendees.

The moderator should ideally be someone who is not heavily engaged or invested in ongoing conversations, as this ensures their ability to objectively guide the meeting without being influenced by personal biases. 

Additionally, promoting inclusivity and diversity within the moderation process can be achieved by rotating the moderator role among team members.  One possibility is to rotate the moderation role between individuals holding formal roles, such as the SIG/TAG leadership, and regular participants. If there is no established pattern within the group, it would be advisable to choose the moderator for the next meeting at the conclusion of each meeting. This would provide the moderator with an opportunity to monitor the agenda for new discussion points and send out pre-meeting communications in a timely manner.
This rotation allows different individuals to take on the responsibility, bringing fresh perspectives and ensuring that a variety of voices are heard. By implementing a rotation system, open source communities can foster a culture that values inclusivity, collaboration, and multiple viewpoints, leading to richer and more well-rounded discussions.

## Setting The Tone and Public Meeting Agenda
In accordance with the principles of the CNCF (Cloud Native Computing Foundation) [code of conduct](https://github.com/cncf/foundation/blob/main/code-of-conduct.md), all meetings are conducted under a framework that upholds respectful and inclusive communication. Clear guidelines are established to ensure that participants engage in a manner that promotes active listening, respects diverse perspectives, and prohibits any form of harassment or discrimination. 

By fostering an environment where every voice is valued and respected, open source communities can cultivate a collaborative and productive atmosphere. Setting a public meeting agenda allows for transparency and enables participants to contribute discussion points in advance, ensuring that relevant topics are included and allowing for efficient and meaningful discussions during the meeting. Detailed note taking should be encouraged and the responsibility shared amongst participants.

## Meeting formalities
To ensure effective communication and a welcoming atmosphere during CNCF meetings, it is important to follow a few guidelines. Firstly, announce upcoming meetings on both the Slack channel and the mailing list to ensure maximum visibility and participation. Additionally, it is crucial to inform all attendees that CNCF meetings are recorded, promoting transparency and accountability. 
Furthermore, make it a point to reference the CNCF code of conduct, emphasizing the importance of respectful and inclusive behavior throughout the meetings. Lastly, provide an opportunity for new participants to introduce themselves, allowing the rest of the attendees to also introduce themselves to the newcomers. This will foster a sense of community and facilitate networking among all participants.

### Facilitating Participation
Implementing "Raise Your Hand" and speaker queuing techniques is crucial for effective open source meeting moderation. By providing clear guidelines to participants on how to express their desire to speak, such as utilizing hand-raising features or using specific keywords in the chat, moderators can ensure a structured and organized discussion. Moderators should be managing speaker queues by actively acknowledging raised hands and maintaining a fair order of speakers. This involves keeping track of the order in which participants indicate their intent to speak and providing opportunities for each person to contribute. 

By implementing these practices, moderators can create an inclusive and participatory environment where everyone has a chance to share their thoughts and ideas, fostering a sense of engagement and equal participation within the open source community.

## Identifying Participants Who Want to Speak
To facilitate active participation and ensure that all voices are heard, moderators should be attentive to identifying participants who want to speak during open source meetings. One effective method is to observe microphone and video activations as potential indicators of a participant's desire to contribute to the discussion. When a participant unmutes their microphone or activates their video camera, it often signals their readiness to engage. 

However, moderators should also be mindful of technical issues that may prevent participants from using audio or video, and be inclusive of those who prefer using chat for communication. By being observant and accommodating different communication preferences, moderators can create an inclusive space that encourages all participants to share their ideas and perspectives, regardless of the mode of communication they choose.

## Addressing Chat Questions and Repeating/Answering Them
Addressing chat questions and actively engaging with participants' comments and concerns is a vital aspect of open source meeting moderation. Moderators should prioritize monitoring the chat for any questions or contributions made by participants. It is important to emphasize the value of inclusivity by ensuring that all voices, whether expressed through chat or other means, receive equal attention. 
Moderators should summarize and address relevant chat messages during the meeting, ensuring that participants' questions are answered and their comments are acknowledged. By actively engaging with the chat, moderators foster a sense of inclusivity, encourage participation from all attendees, and create a space where everyone feels heard and valued.

## Dealing with Disruptive Behavior
Maintaining a respectful and productive meeting environment involves effectively addressing any disruptive behavior that may arise. Moderators should promptly and tactfully address such situations. This may involve providing gentle reminders or redirections to individuals who are veering off-topic or being disruptive. 

If necessary, moderators can utilize muting options or engage in private discussions with the individuals involved to address their concerns or manage their behavior. The goal is to create a positive and inclusive space where everyone feels comfortable expressing their ideas and opinions without disruptions interfering with the overall meeting experience.

Disruptive behavior in a meeting can vary, and it can be helpful to understand how to handle them effectively. For instance, if someone accidentally leaves their microphone on and generates background noise, the moderator can promptly mute their microphone to eliminate the disturbance. Another example is when a particular topic or discussion keeps recurring and deviates from the immediate or planned agenda. In such cases, the moderator can tactfully identify the issue and redirect the conversation, suggesting that the topic be added to the bottom the current agenda for a dedicated discussion that would ensure a thorough exploration without derailing the current topic or it could be saved for a future agenda. These examples demonstrate practical strategies for managing disruptive behavior while maintaining a respectful and productive meeting environment.

## Handling Conflict
Handling conflicts is a critical aspect of effective moderation. Moderators play a crucial role in facilitating discussions when diverse viewpoints arise or potential conflicts emerge. Moderators should encourage active listening, promote understanding and empathy among participants. Emphasizing the importance of respectful dialogue fosters an environment where individuals can express their opinions without fear of judgment or hostility. 

Encouraging the search for common ground helps bridge gaps and build consensus. Moderators should allow for healthy debates, providing space for constructive challenges and exploration of ideas. By promoting open and respectful exchanges, moderators create an atmosphere where conflicts can be navigated effectively, fostering a culture of collaboration and productive outcomes.

There are practical tactics that moderators can employ when handling conflicts in meetings. One effective approach is restating opposing views within the context of the discussion at hand. By saying phrases like, "What I hear you saying is..." or "I want to ensure we're capturing the problem correctly, this is how I understand it...", moderators can help clarify differing perspectives and ensure that all participants have a shared understanding of the issues at stake. This tactic encourages participants to actively engage in the dialogue, express their viewpoints, and actively work towards finding common ground. By incorporating this approach, moderators can navigate conflicts with clarity and promote productive outcomes that emerge from respectful and open exchanges.

## Cheat Sheet
- Announce upcoming meetings on both the Slack channel and the mailing list to ensure maximum visibility and participation.
- Inform all attendees that CNCF meetings are recorded to promote transparency and accountability.
- Reference the CNCF code of conduct, emphasizing the importance of respectful and inclusive behavior throughout the meetings.
- Provide an opportunity for new participants to introduce themselves, allowing the rest of the attendees to also introduce themselves to the newcomers.
- Pre-select a suitable moderator from the pool of regular attendees, considering their demonstrated commitment to the group's work and active participation.
- Rotate the moderation role among regular contributors to distribute the responsibility and ensure diverse perspectives.
- Announce the moderator at the beginning of the meeting and record it in the meeting agenda.
- Set a public meeting agenda to promote transparency and allow participants to contribute discussion points in advance.
- Recorded the names of attendees in the meeting agenda as well as people that announced their absence to the upcoming meeting.
- Implement "Raise Your Hand" and speaker queuing techniques to ensure structured and organized discussions.
- Be attentive to identifying participants who want to speak, observing microphone and video activations as potential indicators.
- Address chat questions and actively engage with participants' comments and concerns to foster inclusivity.
- Promptly and tactfully address disruptive behavior, providing gentle reminders or utilizing muting options if necessary.
- Handle conflicts by encouraging active listening, understanding, and empathy among participants.
- Foster an environment where healthy debates and respectful exchanges can occur to navigate conflicts effectively.
- Encourage the search for common ground and consensus-building to bridge gaps and promote collaboration.
- The moderator should take responsibility for time keeping, ensuring that topics get an appropriate amount of time in order for all topics on the agenda to be covered. Where applicable topics should be further discussed in issues, pull requests and Slack.
- Wherever possible record action items and the people that took responsibility for them in the meeting agenda, keeping in mind that a large part of the purpose of the meeting is to get the work of the group to progress.

## Conclusion
In conclusion, open source meeting moderation plays a pivotal role in fostering inclusivity, enhancing participation, and creating a productive and respectful environment within open source communities. 

Throughout this guide, we have explored various key aspects of effective moderation. By following these guidelines, moderators can ensure that open source meetings are inclusive spaces where diverse voices are valued, respected, and actively engaged. The role of the moderator is instrumental in nurturing collaboration, balancing participation, and creating a learning-focused atmosphere that benefits the entire community. 

By implementing these practices, open source communities can maximize the potential for innovative ideas, comprehensive decision-making, and collective progress. As you embark on your role as a moderator, we encourage you to adapt these principles and strategies to suit the specific needs and dynamics of your open source community, fostering an inclusive and participatory environment where all individuals can contribute, learn, and thrive.
