---
title: Glossary
linkTitle: Glossary
description: A glossary of CNCF-specific terms, including CNCF group acronyms or how projects are organized within our ecosystem.
weight: 3
---
# Introduction

This glossary covers CNCF-specific terms, including CNCF group acronyms or how projects are organized within our ecosystem (for technical definitions, please refer to the [Cloud Native Glossary](https://glossary.cncf.io/). As with everything else on [contribute.cncf.io](https://contribute.cncf.io/), this is a living document, and we encourage anyone seeing gaps to raise an issue or submit a PR. 

# Terms

## Charter
A Charter is a formal document that outlines the purpose, goals, scope, responsibilities, and structure of a particular group or organization. In the context of the CNCF, a Charter may refer to the guiding principles and objectives of a project, [TAG](#technical-advisory-group-tag), [working group](#working-group), or committee. More information about charter can be found in the [Charter guide](https://contribute.cncf.io/maintainers/governance/charter/).

## Cloud Native Ambassador (CNA)
A [Cloud Native Ambassador](https://www.cncf.io/people/ambassadors/) is an individual who acts as a representative and advocate for cloud-native technologies and the CNCF ecosystem. Ambassadors promote awareness, knowledge sharing, and adoption of cloud-native computing concepts.

## Cloud Native Community Groups (CNCG)
Cloud Native Community Groups are subgroups or communities within the CNCF that focus on specific topics, interests, or initiatives. These groups provide a platform for like-minded individuals to connect, collaborate, and share knowledge within the CNCF community. CNCF supports the worldwide community of the CNCGs. They are listed on [community.cncf.io](https://community.cncf.io/) website.

## Cloud Native Computing Foundation (CNCF)
[CNCF](https://www.cncf.io/) is an open-source software foundation that aims to advance the adoption of cloud-native computing technologies. It hosts various projects, promotes community collaboration, and provides a platform for sharing best practices.

## Cloud Native Landscape
[The Cloud Native Landscape](https://landscape.cncf.io/) refers to a visual representation or diagram that showcases the different cloud-native technologies, projects, and companies within the cloud-native ecosystem. It helps provide an overview of the landscape and the relationships between various components. The CNCF Cloud Native Landscape can be found [here](https://landscape.cncf.io/), with its [guide](https://landscape.cncf.io/guide) on how to use it.

## Code of Conduct
A Code of Conduct is a set of guidelines and rules that define the expected behaviour and interactions within a community or organization. [CNCF Code of Conduct](https://github.com/cncf/foundation/blob/main/code-of-conduct.md) promotes inclusivity, respectful communication, and creates a safe environment for collaboration among community members. CNCF Community Code of Conduct has translations in various languages.

## Community member
A community member is an individual who actively engages with and supports an open source community. Community members may contribute, provide feedback, participate in discussions, or advocate for the project within the broader community.

## Contributing Guide
A Contributing Guide is a document or set of instructions that provides guidelines, best practices, and procedures for individuals who want to contribute to an open source project. It helps newcomers understand how to get involved, submit contributions, and engage with the project's community. A recommended template for such a guide can be found [here](https://github.com/cncf/project-template/blob/main/CONTRIBUTING.md).

## Contributor
A contributor is an individual who actively participates in an open source project by submitting code, documentation, bug reports, or other forms of contributions. Contributors play a vital role in improving and extending the functionality of the project.

## Contributor Growth Framework
[Contributor Growth Framework](https://contribute.cncf.io/maintainers/community/contributor-growth-framework/) is a set of guidelines, resources, and mentorship programs aimed at nurturing and supporting the growth and development of contributors within an open source project or community. It provides pathways for contributors to expand their skills and responsibilities.

## Contributor ladder
A contributor ladder is a structured framework or progression path that defines different levels or stages of contributions within an open source project or community. It helps recognize and reward contributors based on their skills, experience, and level of involvement. CNCF's contributor ladder template can be found [here](https://github.com/cncf/project-template/blob/main/CONTRIBUTOR_LADDER.md).

## Contributor License Agreement
A Contributor License Agreement (CLA) is a legal agreement between a contributor and an open source project. It grants the project certain rights to use, modify, and distribute the contributor's contributions while clarifying the ownership and licensing of the contributed code. A project can choose to use either a Contributor License Agreement or the Developer Certificate of Origin. 

## Developer Certificate of Origin 
The Developer Certificate of Origin (DCO) is a per-commit sign-off made by a contributor stating that they agree to the terms published at https://developercertificate.org/ for that particular contribution. Projects can choose either a CLA or a DCO to clarify ownership and licensing of contributed code.

## DevStats
[DevStats](https://devstats.cncf.io/) is a tool or platform used to collect, analyze, and visualize data related to the development and contributions of open source projects. It provides insights into metrics such as code changes, contributions, and [project health](#project-health).

## End User
An end user is an individual or organization that utilizes or benefits from the products, services, or solutions developed by open source projects. End users may provide feedback, report issues, or contribute insights based on their experiences with the project.

## Good first issue (label)
"[Good first issue](https://contribute.cncf.io/maintainers/templates/issue-labels/#good-first-issue)" is a label commonly used in open source projects to identify beginner-friendly tasks or issues that are suitable for newcomers who want to contribute. These issues typically have clear instructions and provide a manageable entry point for new contributors. CNCF's [CLOTributor](https://clotributor.dev/) is a tool that shows the issues with "good first issue" labels as opportunities to start contributing to a project.

## Governance
Governance refers to the set of processes, policies, and structures that guide decision-making, accountability, and overall management of an organization or community. It establishes rules and principles for maintaining order, transparency, and fairness. In CNCF, [open governance](#open-governance) is embraced.

## Graduation
Graduation is the final stage in the [project lifecycle](#project-lifecycle) within the CNCF. Projects that reach the graduation phase have proven to be successful, have a strong community, and meet the CNCF's requirements. Graduated projects are considered mature and self-sustaining.

## Help wanted (label)
"[Help wanted](https://contribute.cncf.io/maintainers/templates/issue-labels/#help-wanted)" is a label used in open source projects to indicate that assistance or contributions are needed for a particular task or issue. It serves as a signal to community members that their help is sought, encouraging them to get involved. CNCF's [CLOTributor](https://clotributor.dev/) is a tool that shows the issues with "help wanted" labels as opportunities to start contributing to a project.

## Incubation
Incubation is the intermediate stage in the [project lifecycle](#project-lifecycle) within the CNCF. Projects in the incubation phase have demonstrated promise, community support, and initial success. They are undergoing further development, maturing, and building a diverse contributor base.

## Lazy consensus
Lazy consensus is a decision-making principle commonly used in open source communities. It means that if no objections or concerns are raised within a specified timeframe, a decision or proposal is considered accepted. Lazy consensus empowers individuals to contribute and make decisions effectively.

## Open Governance
Open Governance refers to a [governance](#governance) model that promotes transparency, inclusivity, and community participation in decision-making processes. Open source projects often adopt open governance to ensure that contributors and community members have a voice in shaping the project's direction. More information about open governance can be found in the [Governance Guide](https://contribute.cncf.io/maintainers/governance/overview/).

## Open Source License
An Open Source license is a legal instrument that grants permissions and defines the terms under which others can use, modify, and distribute an open source project or its source code. Licenses ensure that open source projects remain free and accessible while protecting the rights of contributors. CNCF's approved licenses can be found [here](https://github.com/cncf/foundation/blob/main/allowed-third-party-license-policy.md#approved-licenses-for-allowlist).

## PR workflow
PR workflow refers to the process and steps involved in handling Pull Requests (PRs) within an open source project. It typically includes activities such as submitting a PR, code review, addressing feedback, and merging the changes into the project's codebase. More information about PR workflow and how a successful one will look like can be found [here](https://contribute.cncf.io/maintainers/community/contributor-growth-framework/pr-workflow/).

## Project Health
Project health refers to the overall status and well-being of an open source project. It may include factors such as active development, community engagement, maintenance, documentation, bug resolution, and adoption rate. More information can be found at the [Project Health Measurement guide](https://contribute.cncf.io/maintainers/community/project-health/).

## Project lifecycle
The project lifecycle refers to the various stages or phases through which a project evolves at the CNCF. It includes 3 stages; [sandbox](#sandbox), [incubation](#incubation), and [graduation](#graduation), each with specific criteria and requirements. The project lifecycle process is documented [here](https://github.com/cncf/toc/blob/main/process/README.md).

## Project maintainer
A project maintainer is an individual or a group responsible for managing and overseeing the development, coordination, and overall health of an open source project. Maintainers review contributions, make decisions, and guide the project's direction. In CNCF, term "maintainer" is used over other similar terms such as "committer".

## Project roadmap
A project roadmap is a visual or written representation of the planned development, milestones, and future goals of an open source project. It outlines the project's strategic direction and provides a timeline for upcoming features, enhancements, and releases.

## Project Steering Committee
A Project Steering Committee is a group of individuals responsible for providing strategic guidance, decision-making, and oversight for an open source project. They ensure that the project aligns with its goals, coordinates contributions, and manages project resources. Not every community has a such committee. More information can be found in the [Leadership Selection guide](https://contribute.cncf.io/maintainers/governance/leadership-selection/#types-of-leadership-selection).

## Quorum
Quorum refers to the minimum number of members required for a meeting or decision-making process to be valid. In the context of the CNCF, quorum may be necessary for voting or making significant decisions within committees, [TAG](#technical-advisory-group-tag)s, [working group](#working-group)s, or [governance](#governance) bodies.

## Sandbox
[The Sandbox](https://github.com/cncf/toc/blob/main/process/README.md#sandbox) is the entry point in the [project lifecycle](#project-lifecycle) within the CNCF. It provides a space for projects to experiment, develop ideas, and showcase their potential. Projects in the sandbox are typically early-stage and may not yet have a stable release.

## Security Audit
A security audit is a comprehensive assessment or review of an open source project's code, architecture, and infrastructure to identify potential security vulnerabilities, risks, and weaknesses. Security audits help ensure the project's resilience and protect users from potential threats. More information is available in the [Security Guidelines](https://contribute.cncf.io/maintainers/security/security-guidelines/) document.

## TAG Working Group
A [TAG](#technical-advisory-group-tag) Working Group is a specific working group within the CNCF that operates under the [Technical Advisory Group](#technical-advisory-group-tag) (TAG). It is a community-driven subgroup dedicated to addressing specific technical topics or challenges within the CNCF ecosystem. TAGs list their WGs in their [charter](#charter).

## Technical Advisory Group (TAG)
A [Technical Advisory Group](https://github.com/cncf/toc/blob/main/tags/cncf-tags.md) is a group of experts or individuals with domain-specific knowledge who provide technical guidance and advice on specific topics or projects within the CNCF. TAG members contribute their expertise to help shape and guide the technical direction of the CNCF. List of TAGs can be found in the [cncf/toc repository](https://github.com/cncf/toc/tree/main/tags).

## Technical Oversight Committee (TOC)
[The Technical Oversight Committee](https://github.com/cncf/toc) is a governing body within the CNCF responsible for overseeing the [technical direction](#project-roadmap), [project lifecycle](#project-lifecycle), and overall [technical health of projects](#project-health) hosted under the CNCF. The TOC ensures that projects align with the CNCF's goals and standards.

## TOC Liaison
A TOC Liaison is an individual who serves as a point of contact and facilitates communication between the [Technical Oversight Committee](#technical-oversight-committee-toc) (TOC) and other teams, [TAG](#technical-advisory-group-tag)s, [working group](#working-group)s, or projects within the CNCF. The liaison helps ensure effective coordination and collaboration.

## Working Group
A Working Group is a team or committee within the CNCF focused on a specific area or topic. Working Groups collaborate to address specific challenges, develop standards, and produce documentation or artifacts related to their respective focus areas. List of WGs can be found in the [cncf/toc repository](https://github.com/cncf/toc#working-groups).

